.. Copyright (C) 2022 Cardiff University
.. Custom autosummary template for functions:
..   - use objname instead of fullname in page title

{{ objname | escape | underline }}

.. currentmodule:: {{ module }}

.. autofunction:: {{ objname }}
